@@ -1,6 +1,22 @@
-/********************************************
- GFingerPoken Configuration Dialog
-********************************************/
+/* dialog.c - GFingerPoken Configuration Dialog
+ * Copyright 1999-2000  Martin Hock
+ * Copyright 2005  Bas Wijnen <shevek@fmf.nl>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ */
 
 #include <stdlib.h> /* For initlevel */
 #include <stdio.h> /* For error messages */
@@ -61,7 +77,7 @@ void initlevel() { /* Create new level, put it in grid, etc. */
   if (invisigrid) free(invisigrid); invisigrid = (obj *)calloc(gridx*gridy, sizeof(obj));
   if (markgrid) free(markgrid); markgrid = (obj *)calloc(gridx*gridy, sizeof(obj));
   if (!(grid && invisigrid && markgrid)) {
-    fprintf(stderr, "Insufficient memory for allocating level; needed %d bytes\n",
+    fprintf(stderr, "Insufficient memory for allocating level; needed %zd bytes\n",
 	    3*gridx*gridy*sizeof(obj));
     exit(1);
   }  
@@ -201,7 +217,7 @@ int loadlevel(char *filename) { /* Max 80 char width: Max 20 width levels, so A-
 	if (invisigrid) free(invisigrid); invisigrid = (obj *)malloc(gridx*gridy*sizeof(obj));
 	if (markgrid) free(markgrid); markgrid = (obj *)malloc(gridx*gridy*sizeof(obj));
 	if (!(grid && invisigrid && markgrid)) {
-	  fprintf(stderr, "Insufficient memory for allocating level; needed %d bytes\n",
+	  fprintf(stderr, "Insufficient memory for allocating level; needed %zd bytes\n",
 		  3*gridx*gridy*sizeof(obj));
 	  exit(1);
 	}  
@@ -245,7 +261,7 @@ int loadlevel(char *filename) { /* Max 80 char width: Max 20 width levels, so A-
   return 1; /* Error */
 }
 
-void filesel_destroy_event(GtkWidget *widget, gpointer data) {
+void filesel_destroy_event(GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   gtk_grab_remove(widget);
 }
 
@@ -256,7 +272,7 @@ static gint filecancelbutton_clicked(GtkWidget *widget, gpointer data) {
 }
 */
 
-static gint openfileok_button_clicked(GtkWidget *widget, gpointer data) {
+static gint openfileok_button_clicked(G_GNUC_UNUSED GtkWidget *widget, gpointer data) {
   if (loadlevel(gtk_file_selection_get_filename(GTK_FILE_SELECTION(data)))) {
     gamebox("Error", "Could not load file");
     gtk_widget_destroy(data);
@@ -274,7 +290,7 @@ static gint openfileok_button_clicked(GtkWidget *widget, gpointer data) {
   return FALSE;
 }
 
-static gint savefileok_button_clicked(GtkWidget *widget, gpointer data) {
+static gint savefileok_button_clicked(G_GNUC_UNUSED GtkWidget *widget, gpointer data) {
   if (savelevel(gtk_file_selection_get_filename(GTK_FILE_SELECTION(data)))) 
     gamebox("Error", "Could not save level");
   gtk_widget_destroy(data);
@@ -282,7 +298,7 @@ static gint savefileok_button_clicked(GtkWidget *widget, gpointer data) {
 }
 
 
-static gint openbarbut_event(GtkWidget *widget, gpointer data) {
+static gint openbarbut_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   GtkWidget *filesel = gtk_file_selection_new("Open GFP Game");
   gtk_signal_connect(GTK_OBJECT(filesel), "destroy", (GtkSignalFunc)filesel_destroy_event, filesel);
   gtk_window_set_modal(GTK_WINDOW(filesel), TRUE);
@@ -295,7 +311,7 @@ static gint openbarbut_event(GtkWidget *widget, gpointer data) {
   return FALSE;
 }
 
-static gint savebarbut_event(GtkWidget *widget, gpointer data) {
+static gint savebarbut_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   GtkWidget *filesel = gtk_file_selection_new("Save GFP Game");
   gtk_signal_connect(GTK_OBJECT(filesel), "destroy", (GtkSignalFunc)filesel_destroy_event, filesel);
   gtk_window_set_modal(GTK_WINDOW(filesel), TRUE);
@@ -308,7 +324,7 @@ static gint savebarbut_event(GtkWidget *widget, gpointer data) {
   return FALSE;
 }
 
-static gint dialogwin_delete_event(GtkWidget *widget, GdkEvent *event, gpointer data) {
+static gint dialogwin_delete_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkEvent *event, G_GNUC_UNUSED gpointer data) {
   if (netmode) return FALSE;
   if (gamestatus == 0) {
     gtk_main_quit();
@@ -319,7 +335,7 @@ static gint dialogwin_delete_event(GtkWidget *widget, GdkEvent *event, gpointer
   return TRUE;
 }
 
-static gint cancelbutton_clicked(GtkWidget *widget, gpointer data) {
+static gint cancelbutton_clicked(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   if (netmode) return FALSE;
     if (gamestatus == 0) {
     gtk_main_quit();
@@ -332,7 +348,7 @@ static gint cancelbutton_clicked(GtkWidget *widget, gpointer data) {
   return TRUE;
 }
 
-static gint okbutton_clicked(GtkWidget *widget, gpointer data) {
+static gint okbutton_clicked(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   int i=0, tempsum=0;
   FILE *configfile;
   char configloc[80]; /* Good Enough */
